.. HDDM documentation master file, created by
   sphinx-quickstart on Sat Sep 11 16:47:10 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include :: ../README.rst

Table of Contents:
==================

.. toctree::
    :maxdepth: 2
    
    manual


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
